Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
- type BackupBatchExpansion
- type BackupBatchInterface
- type BackupBatchesGetter
- type BackupBlueprintExpansion
- type BackupBlueprintInterface
- type BackupBlueprintsGetter
- type BackupConfigurationExpansion
- type BackupConfigurationInterface
- type BackupConfigurationsGetter
- type BackupSessionExpansion
- type BackupSessionInterface
- type BackupSessionsGetter
- type FunctionExpansion
- type FunctionInterface
- type FunctionsGetter
- type RestoreBatchExpansion
- type RestoreBatchInterface
- type RestoreBatchesGetter
- type RestoreSessionExpansion
- type RestoreSessionInterface
- type RestoreSessionsGetter
- type StashV1beta1Client
- func (c *StashV1beta1Client) BackupBatches(namespace string) BackupBatchInterface
- func (c *StashV1beta1Client) BackupBlueprints() BackupBlueprintInterface
- func (c *StashV1beta1Client) BackupConfigurations(namespace string) BackupConfigurationInterface
- func (c *StashV1beta1Client) BackupSessions(namespace string) BackupSessionInterface
- func (c *StashV1beta1Client) Functions() FunctionInterface
- func (c *StashV1beta1Client) RESTClient() rest.Interface
- func (c *StashV1beta1Client) RestoreBatches(namespace string) RestoreBatchInterface
- func (c *StashV1beta1Client) RestoreSessions(namespace string) RestoreSessionInterface
- func (c *StashV1beta1Client) Tasks() TaskInterface
- type StashV1beta1Interface
- type TaskExpansion
- type TaskInterface
- type TasksGetter
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BackupBatchExpansion ¶
type BackupBatchExpansion interface{}
type BackupBatchInterface ¶
type BackupBatchInterface interface {
Create(ctx context.Context, backupBatch *v1beta1.BackupBatch, opts v1.CreateOptions) (*v1beta1.BackupBatch, error)
Update(ctx context.Context, backupBatch *v1beta1.BackupBatch, opts v1.UpdateOptions) (*v1beta1.BackupBatch, error)
UpdateStatus(ctx context.Context, backupBatch *v1beta1.BackupBatch, opts v1.UpdateOptions) (*v1beta1.BackupBatch, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1beta1.BackupBatch, error)
List(ctx context.Context, opts v1.ListOptions) (*v1beta1.BackupBatchList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1beta1.BackupBatch, err error)
BackupBatchExpansion
}
BackupBatchInterface has methods to work with BackupBatch resources.
type BackupBatchesGetter ¶
type BackupBatchesGetter interface {
BackupBatches(namespace string) BackupBatchInterface
}
BackupBatchesGetter has a method to return a BackupBatchInterface. A group's client should implement this interface.
type BackupBlueprintExpansion ¶
type BackupBlueprintExpansion interface{}
type BackupBlueprintInterface ¶
type BackupBlueprintInterface interface {
Create(ctx context.Context, backupBlueprint *v1beta1.BackupBlueprint, opts v1.CreateOptions) (*v1beta1.BackupBlueprint, error)
Update(ctx context.Context, backupBlueprint *v1beta1.BackupBlueprint, opts v1.UpdateOptions) (*v1beta1.BackupBlueprint, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1beta1.BackupBlueprint, error)
List(ctx context.Context, opts v1.ListOptions) (*v1beta1.BackupBlueprintList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1beta1.BackupBlueprint, err error)
BackupBlueprintExpansion
}
BackupBlueprintInterface has methods to work with BackupBlueprint resources.
type BackupBlueprintsGetter ¶
type BackupBlueprintsGetter interface {
BackupBlueprints() BackupBlueprintInterface
}
BackupBlueprintsGetter has a method to return a BackupBlueprintInterface. A group's client should implement this interface.
type BackupConfigurationExpansion ¶
type BackupConfigurationExpansion interface{}
type BackupConfigurationInterface ¶
type BackupConfigurationInterface interface {
Create(ctx context.Context, backupConfiguration *v1beta1.BackupConfiguration, opts v1.CreateOptions) (*v1beta1.BackupConfiguration, error)
Update(ctx context.Context, backupConfiguration *v1beta1.BackupConfiguration, opts v1.UpdateOptions) (*v1beta1.BackupConfiguration, error)
UpdateStatus(ctx context.Context, backupConfiguration *v1beta1.BackupConfiguration, opts v1.UpdateOptions) (*v1beta1.BackupConfiguration, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1beta1.BackupConfiguration, error)
List(ctx context.Context, opts v1.ListOptions) (*v1beta1.BackupConfigurationList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1beta1.BackupConfiguration, err error)
BackupConfigurationExpansion
}
BackupConfigurationInterface has methods to work with BackupConfiguration resources.
type BackupConfigurationsGetter ¶
type BackupConfigurationsGetter interface {
BackupConfigurations(namespace string) BackupConfigurationInterface
}
BackupConfigurationsGetter has a method to return a BackupConfigurationInterface. A group's client should implement this interface.
type BackupSessionExpansion ¶
type BackupSessionExpansion interface{}
type BackupSessionInterface ¶
type BackupSessionInterface interface {
Create(ctx context.Context, backupSession *v1beta1.BackupSession, opts v1.CreateOptions) (*v1beta1.BackupSession, error)
Update(ctx context.Context, backupSession *v1beta1.BackupSession, opts v1.UpdateOptions) (*v1beta1.BackupSession, error)
UpdateStatus(ctx context.Context, backupSession *v1beta1.BackupSession, opts v1.UpdateOptions) (*v1beta1.BackupSession, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1beta1.BackupSession, error)
List(ctx context.Context, opts v1.ListOptions) (*v1beta1.BackupSessionList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1beta1.BackupSession, err error)
BackupSessionExpansion
}
BackupSessionInterface has methods to work with BackupSession resources.
type BackupSessionsGetter ¶
type BackupSessionsGetter interface {
BackupSessions(namespace string) BackupSessionInterface
}
BackupSessionsGetter has a method to return a BackupSessionInterface. A group's client should implement this interface.
type FunctionExpansion ¶
type FunctionExpansion interface{}
type FunctionInterface ¶
type FunctionInterface interface {
Create(ctx context.Context, function *v1beta1.Function, opts v1.CreateOptions) (*v1beta1.Function, error)
Update(ctx context.Context, function *v1beta1.Function, opts v1.UpdateOptions) (*v1beta1.Function, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1beta1.Function, error)
List(ctx context.Context, opts v1.ListOptions) (*v1beta1.FunctionList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1beta1.Function, err error)
FunctionExpansion
}
FunctionInterface has methods to work with Function resources.
type FunctionsGetter ¶
type FunctionsGetter interface {
Functions() FunctionInterface
}
FunctionsGetter has a method to return a FunctionInterface. A group's client should implement this interface.
type RestoreBatchExpansion ¶
type RestoreBatchExpansion interface{}
type RestoreBatchInterface ¶
type RestoreBatchInterface interface {
Create(ctx context.Context, restoreBatch *v1beta1.RestoreBatch, opts v1.CreateOptions) (*v1beta1.RestoreBatch, error)
Update(ctx context.Context, restoreBatch *v1beta1.RestoreBatch, opts v1.UpdateOptions) (*v1beta1.RestoreBatch, error)
UpdateStatus(ctx context.Context, restoreBatch *v1beta1.RestoreBatch, opts v1.UpdateOptions) (*v1beta1.RestoreBatch, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1beta1.RestoreBatch, error)
List(ctx context.Context, opts v1.ListOptions) (*v1beta1.RestoreBatchList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1beta1.RestoreBatch, err error)
RestoreBatchExpansion
}
RestoreBatchInterface has methods to work with RestoreBatch resources.
type RestoreBatchesGetter ¶
type RestoreBatchesGetter interface {
RestoreBatches(namespace string) RestoreBatchInterface
}
RestoreBatchesGetter has a method to return a RestoreBatchInterface. A group's client should implement this interface.
type RestoreSessionExpansion ¶
type RestoreSessionExpansion interface{}
type RestoreSessionInterface ¶
type RestoreSessionInterface interface {
Create(ctx context.Context, restoreSession *v1beta1.RestoreSession, opts v1.CreateOptions) (*v1beta1.RestoreSession, error)
Update(ctx context.Context, restoreSession *v1beta1.RestoreSession, opts v1.UpdateOptions) (*v1beta1.RestoreSession, error)
UpdateStatus(ctx context.Context, restoreSession *v1beta1.RestoreSession, opts v1.UpdateOptions) (*v1beta1.RestoreSession, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1beta1.RestoreSession, error)
List(ctx context.Context, opts v1.ListOptions) (*v1beta1.RestoreSessionList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1beta1.RestoreSession, err error)
RestoreSessionExpansion
}
RestoreSessionInterface has methods to work with RestoreSession resources.
type RestoreSessionsGetter ¶
type RestoreSessionsGetter interface {
RestoreSessions(namespace string) RestoreSessionInterface
}
RestoreSessionsGetter has a method to return a RestoreSessionInterface. A group's client should implement this interface.
type StashV1beta1Client ¶
type StashV1beta1Client struct {
// contains filtered or unexported fields
}
StashV1beta1Client is used to interact with features provided by the stash.appscode.com group.
func New ¶
func New(c rest.Interface) *StashV1beta1Client
New creates a new StashV1beta1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*StashV1beta1Client, error)
NewForConfig creates a new StashV1beta1Client for the given config. NewForConfig is equivalent to NewForConfigAndClient(c, httpClient), where httpClient was generated with rest.HTTPClientFor(c).
func NewForConfigAndClient ¶ added in v0.21.0
NewForConfigAndClient creates a new StashV1beta1Client for the given config and http client. Note the http client provided takes precedence over the configured transport values.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *StashV1beta1Client
NewForConfigOrDie creates a new StashV1beta1Client for the given config and panics if there is an error in the config.
func (*StashV1beta1Client) BackupBatches ¶
func (c *StashV1beta1Client) BackupBatches(namespace string) BackupBatchInterface
func (*StashV1beta1Client) BackupBlueprints ¶
func (c *StashV1beta1Client) BackupBlueprints() BackupBlueprintInterface
func (*StashV1beta1Client) BackupConfigurations ¶
func (c *StashV1beta1Client) BackupConfigurations(namespace string) BackupConfigurationInterface
func (*StashV1beta1Client) BackupSessions ¶
func (c *StashV1beta1Client) BackupSessions(namespace string) BackupSessionInterface
func (*StashV1beta1Client) Functions ¶
func (c *StashV1beta1Client) Functions() FunctionInterface
func (*StashV1beta1Client) RESTClient ¶
func (c *StashV1beta1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*StashV1beta1Client) RestoreBatches ¶
func (c *StashV1beta1Client) RestoreBatches(namespace string) RestoreBatchInterface
func (*StashV1beta1Client) RestoreSessions ¶
func (c *StashV1beta1Client) RestoreSessions(namespace string) RestoreSessionInterface
func (*StashV1beta1Client) Tasks ¶
func (c *StashV1beta1Client) Tasks() TaskInterface
type StashV1beta1Interface ¶
type StashV1beta1Interface interface {
RESTClient() rest.Interface
BackupBatchesGetter
BackupBlueprintsGetter
BackupConfigurationsGetter
BackupSessionsGetter
FunctionsGetter
RestoreBatchesGetter
RestoreSessionsGetter
TasksGetter
}
type TaskExpansion ¶
type TaskExpansion interface{}
type TaskInterface ¶
type TaskInterface interface {
Create(ctx context.Context, task *v1beta1.Task, opts v1.CreateOptions) (*v1beta1.Task, error)
Update(ctx context.Context, task *v1beta1.Task, opts v1.UpdateOptions) (*v1beta1.Task, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1beta1.Task, error)
List(ctx context.Context, opts v1.ListOptions) (*v1beta1.TaskList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1beta1.Task, err error)
TaskExpansion
}
TaskInterface has methods to work with Task resources.
type TasksGetter ¶
type TasksGetter interface {
Tasks() TaskInterface
}
TasksGetter has a method to return a TaskInterface. A group's client should implement this interface.