Documentation
¶
Index ¶
- type BackupBatchLister
- type BackupBatchListerExpansion
- type BackupBatchNamespaceLister
- type BackupBatchNamespaceListerExpansion
- type BackupBlueprintLister
- type BackupBlueprintListerExpansion
- type BackupConfigurationLister
- type BackupConfigurationListerExpansion
- type BackupConfigurationNamespaceLister
- type BackupConfigurationNamespaceListerExpansion
- type BackupSessionLister
- type BackupSessionListerExpansion
- type BackupSessionNamespaceLister
- type BackupSessionNamespaceListerExpansion
- type FunctionLister
- type FunctionListerExpansion
- type RestoreBatchLister
- type RestoreBatchListerExpansion
- type RestoreBatchNamespaceLister
- type RestoreBatchNamespaceListerExpansion
- type RestoreSessionLister
- type RestoreSessionListerExpansion
- type RestoreSessionNamespaceLister
- type RestoreSessionNamespaceListerExpansion
- type TaskLister
- type TaskListerExpansion
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BackupBatchLister ¶
type BackupBatchLister interface {
// List lists all BackupBatches in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1beta1.BackupBatch, err error)
// BackupBatches returns an object that can list and get BackupBatches.
BackupBatches(namespace string) BackupBatchNamespaceLister
BackupBatchListerExpansion
}
BackupBatchLister helps list BackupBatches. All objects returned here must be treated as read-only.
func NewBackupBatchLister ¶
func NewBackupBatchLister(indexer cache.Indexer) BackupBatchLister
NewBackupBatchLister returns a new BackupBatchLister.
type BackupBatchListerExpansion ¶
type BackupBatchListerExpansion interface{}
BackupBatchListerExpansion allows custom methods to be added to BackupBatchLister.
type BackupBatchNamespaceLister ¶
type BackupBatchNamespaceLister interface {
// List lists all BackupBatches in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1beta1.BackupBatch, err error)
// Get retrieves the BackupBatch from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1beta1.BackupBatch, error)
BackupBatchNamespaceListerExpansion
}
BackupBatchNamespaceLister helps list and get BackupBatches. All objects returned here must be treated as read-only.
type BackupBatchNamespaceListerExpansion ¶
type BackupBatchNamespaceListerExpansion interface{}
BackupBatchNamespaceListerExpansion allows custom methods to be added to BackupBatchNamespaceLister.
type BackupBlueprintLister ¶
type BackupBlueprintLister interface {
// List lists all BackupBlueprints in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1beta1.BackupBlueprint, err error)
// Get retrieves the BackupBlueprint from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1beta1.BackupBlueprint, error)
BackupBlueprintListerExpansion
}
BackupBlueprintLister helps list BackupBlueprints. All objects returned here must be treated as read-only.
func NewBackupBlueprintLister ¶
func NewBackupBlueprintLister(indexer cache.Indexer) BackupBlueprintLister
NewBackupBlueprintLister returns a new BackupBlueprintLister.
type BackupBlueprintListerExpansion ¶
type BackupBlueprintListerExpansion interface{}
BackupBlueprintListerExpansion allows custom methods to be added to BackupBlueprintLister.
type BackupConfigurationLister ¶
type BackupConfigurationLister interface {
// List lists all BackupConfigurations in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1beta1.BackupConfiguration, err error)
// BackupConfigurations returns an object that can list and get BackupConfigurations.
BackupConfigurations(namespace string) BackupConfigurationNamespaceLister
BackupConfigurationListerExpansion
}
BackupConfigurationLister helps list BackupConfigurations. All objects returned here must be treated as read-only.
func NewBackupConfigurationLister ¶
func NewBackupConfigurationLister(indexer cache.Indexer) BackupConfigurationLister
NewBackupConfigurationLister returns a new BackupConfigurationLister.
type BackupConfigurationListerExpansion ¶
type BackupConfigurationListerExpansion interface{}
BackupConfigurationListerExpansion allows custom methods to be added to BackupConfigurationLister.
type BackupConfigurationNamespaceLister ¶
type BackupConfigurationNamespaceLister interface {
// List lists all BackupConfigurations in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1beta1.BackupConfiguration, err error)
// Get retrieves the BackupConfiguration from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1beta1.BackupConfiguration, error)
BackupConfigurationNamespaceListerExpansion
}
BackupConfigurationNamespaceLister helps list and get BackupConfigurations. All objects returned here must be treated as read-only.
type BackupConfigurationNamespaceListerExpansion ¶
type BackupConfigurationNamespaceListerExpansion interface{}
BackupConfigurationNamespaceListerExpansion allows custom methods to be added to BackupConfigurationNamespaceLister.
type BackupSessionLister ¶
type BackupSessionLister interface {
// List lists all BackupSessions in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1beta1.BackupSession, err error)
// BackupSessions returns an object that can list and get BackupSessions.
BackupSessions(namespace string) BackupSessionNamespaceLister
BackupSessionListerExpansion
}
BackupSessionLister helps list BackupSessions. All objects returned here must be treated as read-only.
func NewBackupSessionLister ¶
func NewBackupSessionLister(indexer cache.Indexer) BackupSessionLister
NewBackupSessionLister returns a new BackupSessionLister.
type BackupSessionListerExpansion ¶
type BackupSessionListerExpansion interface{}
BackupSessionListerExpansion allows custom methods to be added to BackupSessionLister.
type BackupSessionNamespaceLister ¶
type BackupSessionNamespaceLister interface {
// List lists all BackupSessions in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1beta1.BackupSession, err error)
// Get retrieves the BackupSession from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1beta1.BackupSession, error)
BackupSessionNamespaceListerExpansion
}
BackupSessionNamespaceLister helps list and get BackupSessions. All objects returned here must be treated as read-only.
type BackupSessionNamespaceListerExpansion ¶
type BackupSessionNamespaceListerExpansion interface{}
BackupSessionNamespaceListerExpansion allows custom methods to be added to BackupSessionNamespaceLister.
type FunctionLister ¶
type FunctionLister interface {
// List lists all Functions in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1beta1.Function, err error)
// Get retrieves the Function from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1beta1.Function, error)
FunctionListerExpansion
}
FunctionLister helps list Functions. All objects returned here must be treated as read-only.
func NewFunctionLister ¶
func NewFunctionLister(indexer cache.Indexer) FunctionLister
NewFunctionLister returns a new FunctionLister.
type FunctionListerExpansion ¶
type FunctionListerExpansion interface{}
FunctionListerExpansion allows custom methods to be added to FunctionLister.
type RestoreBatchLister ¶
type RestoreBatchLister interface {
// List lists all RestoreBatches in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1beta1.RestoreBatch, err error)
// RestoreBatches returns an object that can list and get RestoreBatches.
RestoreBatches(namespace string) RestoreBatchNamespaceLister
RestoreBatchListerExpansion
}
RestoreBatchLister helps list RestoreBatches. All objects returned here must be treated as read-only.
func NewRestoreBatchLister ¶
func NewRestoreBatchLister(indexer cache.Indexer) RestoreBatchLister
NewRestoreBatchLister returns a new RestoreBatchLister.
type RestoreBatchListerExpansion ¶
type RestoreBatchListerExpansion interface{}
RestoreBatchListerExpansion allows custom methods to be added to RestoreBatchLister.
type RestoreBatchNamespaceLister ¶
type RestoreBatchNamespaceLister interface {
// List lists all RestoreBatches in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1beta1.RestoreBatch, err error)
// Get retrieves the RestoreBatch from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1beta1.RestoreBatch, error)
RestoreBatchNamespaceListerExpansion
}
RestoreBatchNamespaceLister helps list and get RestoreBatches. All objects returned here must be treated as read-only.
type RestoreBatchNamespaceListerExpansion ¶
type RestoreBatchNamespaceListerExpansion interface{}
RestoreBatchNamespaceListerExpansion allows custom methods to be added to RestoreBatchNamespaceLister.
type RestoreSessionLister ¶
type RestoreSessionLister interface {
// List lists all RestoreSessions in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1beta1.RestoreSession, err error)
// RestoreSessions returns an object that can list and get RestoreSessions.
RestoreSessions(namespace string) RestoreSessionNamespaceLister
RestoreSessionListerExpansion
}
RestoreSessionLister helps list RestoreSessions. All objects returned here must be treated as read-only.
func NewRestoreSessionLister ¶
func NewRestoreSessionLister(indexer cache.Indexer) RestoreSessionLister
NewRestoreSessionLister returns a new RestoreSessionLister.
type RestoreSessionListerExpansion ¶
type RestoreSessionListerExpansion interface{}
RestoreSessionListerExpansion allows custom methods to be added to RestoreSessionLister.
type RestoreSessionNamespaceLister ¶
type RestoreSessionNamespaceLister interface {
// List lists all RestoreSessions in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1beta1.RestoreSession, err error)
// Get retrieves the RestoreSession from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1beta1.RestoreSession, error)
RestoreSessionNamespaceListerExpansion
}
RestoreSessionNamespaceLister helps list and get RestoreSessions. All objects returned here must be treated as read-only.
type RestoreSessionNamespaceListerExpansion ¶
type RestoreSessionNamespaceListerExpansion interface{}
RestoreSessionNamespaceListerExpansion allows custom methods to be added to RestoreSessionNamespaceLister.
type TaskLister ¶
type TaskLister interface {
// List lists all Tasks in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1beta1.Task, err error)
// Get retrieves the Task from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1beta1.Task, error)
TaskListerExpansion
}
TaskLister helps list Tasks. All objects returned here must be treated as read-only.
func NewTaskLister ¶
func NewTaskLister(indexer cache.Indexer) TaskLister
NewTaskLister returns a new TaskLister.
type TaskListerExpansion ¶
type TaskListerExpansion interface{}
TaskListerExpansion allows custom methods to be added to TaskLister.